@@ -19,7 +19,7 @@ License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 ****************************************************************************/
 #include "server_decoration.h"
 #include "event_queue.h"
-#include "logging_p.h"
+#include "logging.h"
 #include "surface.h"
 #include "wayland_pointer_p.h"
 
